
.. _builtin_tests:

Tests that come with pyfrc
==========================

pyfrc comes with testing functions that can be used to test basic
functionality of just about any robot, including running through a 
simulated practice match.

.. automodule:: pyfrc.tests
   :members:

.. automodule:: pyfrc.tests.basic
   :members:

Docstring tests
---------------

.. automodule:: pyfrc.tests.docstring_test
   :members:
